Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1331)

Unified Diff: third_party/WebKit/Source/core/input/PointerEventManager.h

Issue 2914673002: Refactor TouchEventManager::TouchInfo class (Closed)
Patch Set: Fix accessing the touch points Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/input/PointerEventManager.h
diff --git a/third_party/WebKit/Source/core/input/PointerEventManager.h b/third_party/WebKit/Source/core/input/PointerEventManager.h
index d8b97b42b300b42052b490b159457fa4b7befd2f..1443ef8956c87b9b59d06c0ced207c9b956d0e20 100644
--- a/third_party/WebKit/Source/core/input/PointerEventManager.h
+++ b/third_party/WebKit/Source/core/input/PointerEventManager.h
@@ -141,15 +141,19 @@ class CORE_EXPORT PointerEventManager
// blockTouchPointers().
void UnblockTouchPointers();
- // Generate the TouchInfos for a WebTouchEvent, hit-testing as necessary.
- void ComputeTouchTargets(const WebTouchEvent&,
- HeapVector<TouchEventManager::TouchInfo>&);
+ // Generate PointerEventTarget for a WebTouchPoint, hit-testing as necessary.
mustaq 2017/05/31 18:22:44 Nit: "Returns..."
Navid Zolghadr 2017/06/01 17:57:51 Done.
+ EventHandlingUtil::PointerEventTarget ComputePointerEventTarget(
+ const WebTouchPoint&);
// Sends touch pointer events and sets consumed bits in TouchInfo array
// based on the return value of pointer event handlers.
- void DispatchTouchPointerEvents(const WebTouchEvent&,
- const Vector<WebTouchEvent>& coalesced_events,
- HeapVector<TouchEventManager::TouchInfo>&);
+ void DispatchTouchPointerEvent(
+ const WebTouchPoint&,
+ const EventHandlingUtil::PointerEventTarget&,
+ const Vector<std::pair<WebTouchPoint, TimeTicks>>& coalesced_events,
+ WebInputEvent::Modifiers,
+ double timestamp,
+ uint32_t unique_touch_event_id);
// Returns whether the event is consumed or not.
WebInputEventResult SendTouchPointerEvent(EventTarget*, PointerEvent*);

Powered by Google App Engine
This is Rietveld 408576698